.hljs-dark{display:block;overflow-x:auto;padding:.5em;color:#f8f8f2}.hljs-dark .hljs-keyword,.hljs-dark .hljs-link,.hljs-dark .hljs-literal,.hljs-dark .hljs-number,.hljs-dark .hljs-section,.hljs-dark .hljs-selector-tag{color:#8be9fd}.hljs-dark .hljs-function .hljs-keyword{color:#ff79c6}.hljs-dark .hljs-addition,.hljs-dark .hljs-attribute,.hljs-dark .hljs-bullet,.hljs-dark .hljs-name,.hljs-dark .hljs-string,.hljs-dark .hljs-symbol,.hljs-dark .hljs-template-tag,.hljs-dark .hljs-template-variable,.hljs-dark .hljs-title,.hljs-dark .hljs-type,.hljs-dark .hljs-variable{color:#f1fa8c}.hljs-dark .hljs-comment,.hljs-dark .hljs-deletion,.hljs-dark .hljs-meta,.hljs-dark .hljs-quote{color:#6272a4}.hljs-dark .hljs-doctag,.hljs-dark .hljs-keyword,.hljs-dark .hljs-literal,.hljs-dark .hljs-name,.hljs-dark .hljs-section,.hljs-dark .hljs-selector-tag,.hljs-dark .hljs-strong,.hljs-dark .hljs-title,.hljs-dark .hljs-type{font-weight:700}.hljs-dark .hljs-emphasis{font-style:italic}.hljs-light{display:block;overflow-x:auto;padding:.5em;color:#333}.hljs-light .hljs-comment,.hljs-light .hljs-quote{color:#998;font-style:italic}.hljs-light .hljs-keyword,.hljs-light .hljs-selector-tag,.hljs-light .hljs-subst{color:#333;font-weight:700}.hljs-light .hljs-literal,.hljs-light .hljs-number,.hljs-light .hljs-tag .hljs-attr,.hljs-light .hljs-template-variable,.hljs-light .hljs-variable{color:teal}.hljs-light .hljs-doctag,.hljs-light .hljs-string{color:#d14}.hljs-light .hljs-section,.hljs-light .hljs-selector-id,.hljs-light .hljs-title{color:#900;font-weight:700}.hljs-light .hljs-subst{font-weight:400}.hljs-light .hljs-class .hljs-title,.hljs-light .hljs-type{color:#458;font-weight:700}.hljs-light .hljs-attribute,.hljs-light .hljs-name,.hljs-light .hljs-tag{color:navy;font-weight:400}.hljs-light .hljs-link,.hljs-light .hljs-regexp{color:#009926}.hljs-light .hljs-bullet,.hljs-light .hljs-symbol{color:#990073}.hljs-light .hljs-built_in,.hljs-light .hljs-builtin-name{color:#0086b3}.hljs-light .hljs-meta{color:#999;font-weight:700}.hljs-light .hljs-deletion{background:#fdd}.hljs-light .hljs-addition{background:#dfd}.hljs-light .hljs-emphasis{font-style:italic}.hljs-light .hljs-strong{font-weight:700}span.find-kws{background-color:#ffd800}
/*# sourceMappingURL=12.d41b9198.chunk.css.map */